@@ -1,6 +1,6 @@
 #!/usr/bin/php
 <?php
-// Slight BBS, Basic telnet "BBS" for PHP/Linux (v0.91)
+// Slight BBS, Basic telnet "BBS" for PHP/Linux (v0.92)
 // Inspired by, but not a clone of, bboard on sdf.org
 // run from inetd/xinetd on whatever port you'd like
 
@@ -109,7 +109,7 @@ function getLine () {
 	global $nl;
 	// get a line from STDIN, and handle timeout
 	$getLine = fgets(STDIN);
-	$getLine = trim($getLine);
+	$getLine = rtrim($getLine);
 
 	// timeout
 	$timeOutCheck = stream_get_meta_data(STDIN);
@@ -135,7 +135,7 @@ function getMultiLines () {
 	while (strtolower($bodyLine) != "/done") {
 		$bodyLine = "";
 		$bodyLine = fgets(STDIN);
-		$bodyLine = trim($bodyLine);
+		$bodyLine = rtrim($bodyLine);
 
 		// timeout check
 		$timeOutCheck = stream_get_meta_data(STDIN);
@@ -303,7 +303,10 @@ $data = "";
 $data1 = "";
 $prompt = "COMMAND (h for help)";
 $cmdCount = 0;
-$passCommand = "";	// use: break out of a case but jump into another
+$passCommand = "l";	// use: break out of a case but jump into another
+			// Set passCommand to something here before the command loop 
+			// if you want a default initial command
+
 $passArg = "";		// use: after breaking and jumping, pass yet another item to that case
 
 while($data != "q" && $data != "Q") {
@@ -408,6 +411,7 @@ while($data != "q" && $data != "Q") {
 							echo "Pin saved. You can now login and post.".$nl;
 							$validEmails[] = $email;
 							$validUsers[$email] = $pin;
+							logEntry("Validated $email");
 						}
 					}
 					fclose($fp);
@@ -469,7 +473,7 @@ while($data != "q" && $data != "Q") {
 
 					$message = "Thanks for validating your email for use on jozhaus.com port 2323. Please reconnect to the BBS and (v)alidate with the following code. This code is NOT your pin; you will create your pin after you validate.".$nl.$nl."     CODE: $validCode".$nl;
 					mail($email,"Jozhaus BBS email validation",$message);
-					logEntry("Validation email sent to $email");
+					logEntry("Validation sent $email");
 
 					echo "Validation message sent to $email.".$nl;
 					echo ct("Please check your email and come back to validate the code.","green").$nl;
@@ -531,6 +535,9 @@ while($data != "q" && $data != "Q") {
 			$gotoBoard = strtoupper($gotoBoard);
 
 			if($gotoBoard == "") {
+				// bboard style behavior, if they hit g but don't enter anything if gives a list
+				echo "No board name specified. Here's a list:".$nl;
+				$passCommand = "l";
 				break;
 			}
 
@@ -960,6 +967,7 @@ while($data != "q" && $data != "Q") {
 					echo $clearScreen;
 					echo "You are authenticated for this session.".$nl;
 					$loggedIn = $email;
+					logEntry("Login $email");
 				} else {
 					echo "The pin you entered was incorrect.".$nl;
 				}
